|
|
|
| Description |
|
|
| Synopsis |
|
|
|
| Documentation |
|
|
| Constructors | | Instances | |
|
|
|
| Constructors | | Instances | |
|
|
|
| Constructors | | Instances | |
|
|
|
| Constructors | | Instances | |
|
|
|
| Constructors | | Instances | |
|
|
|
| Constructors | | Instances | |
|
|
|
| Constructors | | Instances | |
|
|
|
| Constructors | | Variable | | | Field | | | Constructor | | | Data | | | Type | | | Newtype | | | Class | | | Method | | | Instance | | | Keyword | | | Extension | | | ModName | | | QualModName | | | Error | |
| Instances | |
|
|
|
| Constructors | | Instances | |
|
|
|
|
|
|
|
|
|
|
| The definition module
|
|
|
| The exporting module
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
| class SymbolTable alpha where | Source |
|
| | Methods | | | | | | | | | | | | | | symUnion :: alpha -> alpha -> alpha | Source |
|
| | Instances | |
|
|
|
| Constructors | | Instances | |
|
|
|
|
|
|
|
|
|
|
|
| Constructors | | Location | | | locationSLine :: Int | | | locationSCol :: Int | | | locationELine :: Int | | | locationECol :: Int | |
|
| Instances | |
|
|
|
| A portion of the source, spanning one or more lines and zero or more columns.
| | Constructors | | SrcSpan | | | srcSpanFilename :: String | | | srcSpanStartLine :: Int | | | srcSpanStartColumn :: Int | | | srcSpanEndLine :: Int | | | srcSpanEndColumn :: Int | |
|
| Instances | |
|
|
|
| Constructors | | PackageScope Bool | | | WorkspaceScope Bool | | | SystemScope | |
| Instances | |
|
|
|
| Constructors | | SystemCommand | | | | WorkspaceCommand | | | | ParseHeaderCommand | | |
| Instances | |
|
|
|
| Constructors | | Instances | |
|
|
|
|
|
|
|
|
|
| An import declaration.
| | Constructors | | ImportDecl | | | importLoc :: Location | | | importModule :: String | name of the module imported.
| | importQualified :: Bool | imported qualified?
| | importSrc :: Bool | imported with {-# SOURCE #-}?
| | importPkg :: Maybe String | imported with explicit package name
| | importAs :: Maybe String | optional alias name in an as clause.
| | importSpecs :: Maybe ImportSpecList | optional list of import specifications.
|
|
| Instances | |
|
|
|
| An explicit import specification list.
| | Constructors | | Instances | |
|
|
|
| An import specification, representing a single explicit item imported
(or hidden) from a module.
| | Constructors | | IVar String | variable
| | IAbs String | T:
the name of a class, datatype or type synonym.
| | IThingAll String | T(..):
a class imported with all of its methods, or
a datatype imported with all of its constructors.
| | IThingWith String [String] | T(C_1,...,C_n):
a class imported with some of its methods, or
a datatype imported with some of its constructors.
|
| Instances | |
|
|
|
|
|
| Constructors | | RetrieveThenBuild | | | BuildThenRetrieve | | | NeverRetrieve | |
| Instances | |
|
|
| Produced by Haddock version 2.6.1 |